@@ -5,15 +5,16 @@ import pickle
 class ProblemDefinition:
     """
     defines a boundary value problem.
-    properties:
-    num_ODE - the number of first order ordinary differential equations in the problem
-    num_parameters - the number of unknown parameters in the problem
-    num_left_boundary_conditions - the number of boundary conditions enforced on the left boundary
-    boundary_points - array that defines the two boundary points on the x axis
-    function - function which evaluates the ODEs that make up the boundary value problem
-    boundary_conditions - function which evaluates the difference between the boundary conditions and the values of the variables at the boundary points
-    function_derivative - evaluates the derivatives of function
-    boundary_conditions_derivative - evaluates the derivatives of bounday_conditions
+    Public Properties:
+        num_ODE - the number of first order ordinary differential equations in the problem
+        num_parameters - the number of unknown parameters in the problem
+        num_left_boundary_conditions - the number of boundary conditions enforced on the left boundary
+        boundary_points - array (length 2) that defines the two boundary points on the x axis
+        function - function which evaluates the ODEs that make up the boundary value problem
+        boundary_conditions - function which evaluates the difference between the boundary
+            conditions and the values of the variables at the boundary points
+        [function_derivative] - function which evaluates the derivatives of function
+        [boundary_conditions_derivative] - function which evaluates the derivatives of bounday_conditions
     """
     def __init__(self,
                  num_ODE,
@@ -47,7 +48,7 @@ class ProblemDefinition:
                 BCA - array of the difference between the boundary condition and variables at the left boundary
                 BCB - array of the difference between the boundary condition and variables at the right boundary
 
-        function_derivative - a function which returns the partial derivatives of the function argument
+        [function_derivative] - a function which returns the partial derivatives of the function argument
             arguments (same as function):
                 X - scalar value of x at which
                 Y - (array) current value of all variables
@@ -57,7 +58,7 @@ class ProblemDefinition:
                 - [array of partial derivative of all ODEs with respect to all unknown parameters; index of ODEs is first, index of parameters is second]
                     must not be returned if the problem does not include unknown parameters
 
-        boundary_conditions_drivative - a function which returns the partial derivatives of the boundary_conditions argument
+        [boundary_conditions_drivative] - a function which returns the partial derivatives of the boundary_conditions argument
             arguments (same as boundary_conditions):
                 YA - (array) value of all variables at the left boundary
                 YB - (array) value of all variables at the right boundary
@@ -120,6 +121,7 @@ class ProblemDefinition:
             if self.function_derivativep is None:
                 self.function_derivativep = fp_dummy
 
+
             if self.boundary_conditions_derivativep is None:
                 self.boundary_conditions_derivativep = bcderivep_dummy
 
@@ -363,7 +365,7 @@ class ProblemDefinition:
                                      + "\nNumerical is:\n" + str(bcB_param_derivative_num))
 
                 else:
-                    bcA_derivative_calc,bcB_derivative_calc = self.boundary_conditions_derivativep(test_solution.solution[:, 0],
+                    bcA_derivative_calc,bcB_derivative_calc = self.boundary_conditions_derivative(test_solution.solution[:, 0],
                                                                                                    test_solution.solution[:,endPoint])
 
                     bcA_derivative_num = numpy.zeros((self.num_left_boundary_conditions, self.num_ODE))
@@ -374,8 +376,8 @@ class ProblemDefinition:
                         delta = numpy.zeros(self.num_ODE)
                         delta[i] += step
 
-                        point1A, point1B = self.boundary_conditionsp(test_solution.solution[:, 0],test_solution.solution[:, endPoint])
-                        point2A, point2B = self.boundary_conditionsp(test_solution.solution[:, 0] + delta ,test_solution.solution[:, endPoint] + delta)
+                        point1A, point1B = self.boundary_conditions(test_solution.solution[:, 0],test_solution.solution[:, endPoint])
+                        point2A, point2B = self.boundary_conditions(test_solution.solution[:, 0] + delta ,test_solution.solution[:, endPoint] + delta)
 
                         bcA_derivative_num[:, i] = (point2A - point1A)/step
                         bcB_derivative_num[:, i] = (point2B - point1B)/step
