@@ -453,7 +453,9 @@ subroutine bvp_extend_wrap(NODE_in,NPAR_in, LEFTBC_in ,NPTS_in,INFO_in, MXNSUB_i
 		MXNSUB_in ,X_in , Y_in, PARAMETERS_in, work_in, iwork_in)
 
 		output_sol = BVP_EXTEND(input_sol, ANEW, BNEW, order, P, MAX_NUM_SUBINTERVALS)
-
+		IF (.NOT. (NPAR_in > 0)) THEN
+			NULLIFY (output_sol%PARAMETERS)
+		END IF
 		CALL mparams_f_sol(output_sol)
 
 end subroutine
